/* ccgo: igs/stats_box.cc
 * 
 * Copyright 2002 Chun-Chung Chen <cjj@u.washington.edu>
 * 
 * This program is free software; you can redistribute it and'or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#include "stats_box.hh"
#include <gtkmm/box.h>
#include <gtkmm/button.h>
#include <gtkmm/stock.h>
#include <gtkmm/buttonbox.h>
#include <gtkmm/scrolledwindow.h>
#include <iostream>
#include <sstream>

using namespace igs;

// void StatsBox::on_show()
// {
// 	VBox::on_show();
// 	if (player.playing <= 0 && player.observing <= 0) state_box.hide();
// }

void StatsBox::hit_game()
{
	if (player.playing > 0) {
		select_game(player.playing);
		return;
	}		
	if (player.observing > 0) {
		select_game(player.observing);
		return;
	}
}

// void StatsBox::refresh()
// {
// 	stats_refresh(name);
// }

StatsBox::StatsBox(const std::string & n) :
	name(n)
{
	// set_title(std::string("Player: ") + name);
	// Gtk::VBox * vb = Gtk::manage(new Gtk::VBox);
	// add(* vb);
	Gtk::HBox * hb;
	Gtk::Label * lb;

	hb = Gtk::manage(new Gtk::HBox);
	pack_start(* hb, Gtk::PACK_SHRINK);
	lb = Gtk::manage(new Gtk::Label("Player: "));
	hb->pack_start(* lb, Gtk::PACK_SHRINK);
	lb = Gtk::manage(new Gtk::Label(name));
	hb->pack_start(* lb, Gtk::PACK_SHRINK);
	lb->set_selectable(true);

	hb = Gtk::manage(new Gtk::HBox);
	pack_start(* hb, Gtk::PACK_SHRINK);
	lb = Gtk::manage(new Gtk::Label("Rating: "));
	hb->pack_start(* lb, Gtk::PACK_SHRINK);
	hb->pack_start(rank, Gtk::PACK_SHRINK);

	hb = Gtk::manage(new Gtk::HBox);
	pack_start(* hb, Gtk::PACK_SHRINK);
	lb = Gtk::manage(new Gtk::Label("Rated Games: "));
	hb->pack_start(* lb, Gtk::PACK_SHRINK);
	hb->pack_start(rated_games, Gtk::PACK_SHRINK);

	hb = Gtk::manage(new Gtk::HBox);
	pack_start(* hb, Gtk::PACK_SHRINK);
	lb = Gtk::manage(new Gtk::Label("Idle Time: "));
	hb->pack_start(* lb, Gtk::PACK_SHRINK);
	hb->pack_start(idle_time, Gtk::PACK_SHRINK);

	pack_start(state_box, Gtk::PACK_SHRINK);
	state_box.pack_start(state, Gtk::PACK_SHRINK);
	state_box.pack_start(game, Gtk::PACK_SHRINK);
	game.signal_clicked().connect(SigC::slot(* this, & StatsBox::hit_game));

	hb = Gtk::manage(new Gtk::HBox);
	pack_start(* hb, Gtk::PACK_SHRINK);
	lb = Gtk::manage(new Gtk::Label("Address: "));
	hb->pack_start(* lb, Gtk::PACK_SHRINK);
	hb->pack_start(address, Gtk::PACK_SHRINK);
	address.set_selectable(true);

	hb = Gtk::manage(new Gtk::HBox);
	pack_start(* hb, Gtk::PACK_SHRINK);
	lb = Gtk::manage(new Gtk::Label("Info: "));
	hb->pack_start(* lb, Gtk::PACK_SHRINK);
// 	hb->pack_start(info, Gtk::PACK_SHRINK);

	Gtk::ScrolledWindow * sw = Gtk::manage(new Gtk::ScrolledWindow);
	sw->set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
	sw->add(info_box);
	pack_start(* sw, Gtk::PACK_SHRINK);
	info_box.set_editable(false);
	info_box.set_cursor_visible(false);
	info_box.set_wrap_mode(Gtk::WRAP_WORD);

// 	Gtk::HButtonBox * bb = Gtk::manage(new Gtk::HButtonBox);
// 	pack_end(* bb, Gtk::PACK_SHRINK);

// 	Gtk::Button * bt;

// 	bt = Gtk::manage(new Gtk::Button(Gtk::Stock::REFRESH));
// 	bb->pack_start(* bt, Gtk::PACK_SHRINK);
// 	bt->signal_clicked().connect(SigC::slot(* this, & StatsBox::refresh));

// 	bt = Gtk::manage(new Gtk::Button(Gtk::Stock::CLOSE));
// 	bb->pack_start(* bt, Gtk::PACK_SHRINK);
// 	bt->signal_clicked().connect(SigC::bind(stats_close.slot(), this));

	show_all();
	state_box.hide(); //
}

StatsBox::~StatsBox()
{
	// std::cerr << "deleting StatsBox" << std::endl;
}

void StatsBox::update(const Player & p)
{

	player.update(p);

	rank.set_text(player.get_rank().long_text());

	std::ostringstream o;
	o << player.get_rated_games();
	rated_games.set_text(o.str());
	idle_time.set_text(player.get_idle().long_text());
	
	address.set_text(player.get_address());
	// info.set_text(player.get_info());
	info_box.get_buffer()->set_text(player.get_info());

	if (p.playing <= 0 && p.observing <= 0) state_box.hide();
	else {
		o.str("");
		state_box.show();
		if (p.playing > 0) {
			state.set_text("Playing in game: ");
			o << p.playing;
		} else {
			state.set_text("Observing game: ");
			o << p.observing;
		}
		game.set_label(o.str());
	}
}

void StatsBox::attach_result(const Result & r)
{
	std::cerr << "attaching result  W=" << r.white << " B=" << r.black << std::endl;
}
