/* ccgo: time.cc
 * 
 * Copyright 2002 Chun-Chung Chen <cjj@u.washington.edu>
 * 
 * This program is free software; you can redistribute it and'or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#include "time.hh"
#include <sstream>
#include <glibmm.h>

using namespace go;

bool Time::tick()
{
	if (! run) return true;
	ticking ++;
	if (ticking < 10) return true;
	ticking = 0;
	if (turn == TURN_BLACK) {
		if (b_time > 0) {
			b_time --;
			if (b_time == 0) {
				if (b_move < 0) {
					b_time = byo_time;
					b_move = byo_move;
				} else {
					timeup(turn);
				}
			}
			update_timing();
		}
	} else {
		if (w_time > 0) {
			w_time --;
			if (w_time == 0) {
				if (w_move < 0) {
					w_time = byo_time;
					w_move = byo_move;
				} else {
					timeup(turn);
				}
			}
			update_timing();
		}
	}
	return true;
}

void Time::update_timing()
{
	std::ostringstream s;
	s << "W:" << w_time / 60 << ":" << (w_time % 60) / 10 << w_time % 10 << "/";
	if (w_move < 10) s << ' ';
	if (w_move >= 0) s << w_move;
	else s << "-";
	w_timing.set_text(s.str());
	s.str("");
	s << "B:" << b_time / 60 << ":" << (b_time % 60) / 10 << b_time % 10 << "/";
	if (b_move < 10) s << ' ';
	if (b_move >= 0) s << b_move;
	else s << "-";
	b_timing.set_text(s.str());
}

Time::Time()
{
	run = false;
	turn = TURN_BLACK;
	pack_start(w_timing, Gtk::PACK_SHRINK);
	pack_start(b_timing, Gtk::PACK_SHRINK);
	time_con = Glib::signal_timeout().connect(SigC::slot(* this, & Time::tick), 100);
}

Time::~Time()
{
	// std::cerr << "deleting time" << std::endl;
	time_con.disconnect();
}

void Time::setup(int t, int yt, int ym)
{
	time = t;
	byo_time = yt;
	byo_move = ym;
	w_time = time;
	b_time = time;
	w_move = -1;
	b_move = -1;
	ticking = 0;
	run = false;
	update_timing();
	set_sensitive(false);
}

void Time::calibrate(int wt, int wm, int bt, int bm)
{
	w_time = wt;
	if (w_time < 0) w_time = 0;
	w_move = wm;
	b_time = bt;
	if (b_time < 0) b_time = 0;
	b_move = bm;
	ticking = 0;
	update_timing();
}

void Time::start()
{
	run = true;
	set_sensitive(true);
}

void Time::stop()
{
	run = false;
	set_sensitive(false);
}

void Time::toggle()
{
	if (turn == TURN_BLACK) {
		if (b_move > 0) b_move --;
		turn = TURN_WHITE;
		if (w_move == 0) {
			w_time = byo_time;
			w_move = byo_move;
		}
	} else {
		if (w_move > 0) w_move --;
		turn = TURN_BLACK;
		if (b_move == 0) {
			b_time = byo_time;
			b_move = byo_move;
		}
	}
}
