/* ccgo: view_win.cc
 * 
 * Copyright 2002 Chun-Chung Chen <cjj@u.washington.edu>
 * 
 * This program is free software; you can redistribute it and'or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#include "view_win.hh"
#include "prop_node.hh"
#include "sgf/sgf.hh"
#include <fstream>

using namespace go;

Node * ViewWin::load_tree_from_file(const std::string & fn)
{
	std::ifstream f(fn.c_str());
	if (f.fail()) {
		node = new Node;
	} else {
		sgf::Tree * t = sgf::load_tree(f);
		if (t == NULL) node = new Node;
		else {
			node = new PropNode(* t);
			delete t;
		}
	}
	return node;
}

void ViewWin::on_hide()
{
	delete this;
}

ViewWin::ViewWin(const std::string & fn) :
	view(load_tree_from_file(fn))
{
	if (dynamic_cast<ProperNode *>(node) == NULL) {
		delete this;
		return;
	}
	add(view);
	Gtk::Button * bt = Gtk::manage(new Gtk::Button("Close"));
	view.get_button_area().pack_start(* bt, Gtk::PACK_SHRINK);
	bt->signal_clicked().connect(slot(* this, & Widget::hide));
	set_default_size(260, 360);
	show_all();
}

ViewWin::~ViewWin()
{
	delete node;
	// std::cerr << "ViewWin deleted!" << std::endl;
}
